@@ -1,15 +1,18 @@
 package HTML::FillInForm::Lite;
-
 use 5.006_000; # 5.6.0
 
 use strict;
 use warnings;
-use Carp ();
-use Scalar::Util ();
+
+our $VERSION  = '1.09';
+
+use Exporter ();
+our @ISA       = qw(Exporter);
+our @EXPORT_OK = qw(fillinform);
 
 #use Smart::Comments '####';
-
-our $VERSION  = '1.08';
+use Carp ();
+use Scalar::Util ();
 
 # Regexp for HTML tags
 
@@ -68,6 +71,21 @@ else {
     *utf8_decode = *is_utf8 = sub { 0 };
 }
 
+sub fillinform { # function interface to fill()
+    if(@_ == 1) {
+        my($data) = @_;
+        my $fif = __PACKAGE__->new();
+        return sub {
+            my($form) = @_;
+            return $fif->fill(\$form, $data);
+        }
+    }
+    else {
+        my($form, $data) = @_;
+        return __PACKAGE__->fill(\$form, $data);
+    }
+}
+
 # utilities for getting HTML attributes
 sub _unquote{
     $_[0] =~ /(['"]) (.*) \1/xms ? $2 : $_[0]; # ' for poor editors
@@ -192,13 +210,20 @@ sub fill :method{
         $content = join q{}, @{$src};
     }
     else{
-        if(!Scalar::Util::openhandle($src)){
-            open my($in), '<'.$context->{layer}, $src
-                or Carp::croak("Cannot open '$src': $!");
-            $src = $in;
+        my $is_fh = Scalar::Util::openhandle($src);
+
+        if($is_fh or !ref($src)) {
+            if(!$is_fh){
+                open my($in), '<'.$context->{layer}, $src
+                    or Carp::croak("Cannot open '$src': $!");
+                $src = $in;
+            }
+            local $/;
+            $content = readline($src); # slurp
+        }
+        else {
+            $content = ${$src};
         }
-        local $/;
-        $content = readline($src); # slurp
     }
 
     # if $content is utf8-flagged, params should be utf8-encoded
@@ -624,7 +649,7 @@ HTML::FillInForm::Lite - Lightweight FillInForm module in Pure Perl
 
 =head1 VERSION
 
-The document describes HTML::FillInForm::Lite version 1.08
+The document describes HTML::FillInForm::Lite version 1.09
 
 =head1 SYNOPSIS
 
@@ -655,6 +680,12 @@ The document describes HTML::FillInForm::Lite version 1.08
     my $cd = Music::CD->retrieve(1);
     $output = $h->fill(\$html, $cd);
 
+    # simple function interface
+    use HTML::FillInForm::Lite qw(fillinform);
+
+    # the same as HTML::FillInForm::Lite->fill(...)
+    $output = fillinform(\$html, $q);
+
 =head1 DESCRIPTION
 
 This module fills in HTML forms with Perl data,
@@ -664,6 +695,19 @@ not using C<HTML::Parser>.
 The difference in the parsers makes C<HTML::FillInForm::Lite> about 2
 times faster than C<HTML::FillInForm>.
 
+=head1 FUNCTIONS
+
+=head2 fillinform(source, form_data)
+
+Simple interface to the C<fill()> method, accepting only a string.
+If you pass a single argument to this function, it is interpreted as
+I<form_data>, and returns a function that accepts I<source>.
+
+    my $fillinform = fillinform($query);
+    $fillinform->($html); # the same as fillinform($html, $query)
+
+This function is exportable.
+
 =head1 METHODS
 
 =head2 new(options...)
